import { amountToInteger } from '../utils.js';
import Fallback from './integration-bank.js';
/** @type {import('./bank.interface.js').IBank} */
export default {
    ...Fallback,
    institutionIds: ['DANSKEBANK_DABANO22'],
    normalizeTransaction(transaction, booked) {
        const editedTrans = { ...transaction };
        /**
         * Danske Bank appends the EndToEndID: NOTPROVIDED to
         * remittanceInformationUnstructured, cluttering the data.
         *
         * We clean thais up by removing any instances of this string from all transactions.
         *
         */
        editedTrans.remittanceInformationUnstructured =
            transaction.remittanceInformationUnstructured.replace('\nEndToEndID: NOTPROVIDED', '');
        return Fallback.normalizeTransaction(transaction, booked, editedTrans);
    },
    calculateStartingBalance(sortedTransactions = [], balances = []) {
        const currentBalance = balances.find(balance => balance.balanceType === 'interimAvailable');
        return sortedTransactions.reduce((total, trans) => {
            return total - amountToInteger(trans.transactionAmount.amount);
        }, amountToInteger(currentBalance.balanceAmount.amount));
    },
};
